=========================
Sample Configuration File
=========================

The following is a sample tacker configuration for adaptation and use. For a
detailed overview of all available configuration options, refer to
:doc:`/configuration/config`.

The sample configuration can also be viewed in :download:`file form
</_static/tacker.conf.sample>`.

.. important::

   The sample configuration file is auto-generated from tacker when this
   documentation is built. You must ensure your version of tacker matches the
   version of this documentation.

.. literalinclude:: /_static/tacker.conf.sample
